package com.phm.manage.service;

import com.phm.manage.domain.Maintenance;

import java.util.List;

/**
 * 维护信息Service接口
 *
 * @author phm
 * @date 2023-08-22
 */
public interface IMaintenanceService {
    /**
     * 查询维护信息
     *
     * @param id 维护信息主键
     * @return 维护信息
     */
    public Maintenance selectMaintenanceById(Long id);

    /**
     * 查询维护信息列表
     *
     * @param maintenance 维护信息
     * @return 维护信息集合
     */
    public List<Maintenance> selectMaintenanceList(Maintenance maintenance);

    /**
     * 新增维护信息
     *
     * @param maintenance 维护信息
     * @return 结果
     */
    public int insertMaintenance(Maintenance maintenance);

    /**
     * 修改维护信息
     *
     * @param maintenance 维护信息
     * @return 结果
     */
    public int updateMaintenance(Maintenance maintenance);

    /**
     * 批量删除维护信息
     *
     * @param ids 需要删除的维护信息主键集合
     * @return 结果
     */
    public int deleteMaintenanceByIds(Long[] ids);

    /**
     * 删除维护信息信息
     *
     * @param id 维护信息主键
     * @return 结果
     */
    public int deleteMaintenanceById(Long id);
}
